"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.FullStoryPlugin = void 0;
var _analyticsReactNative = require("@segment/analytics-react-native");
var _reactNative = _interopRequireDefault(require("@fullstory/react-native"));
var _FSProperties = require("./utils/FSProperties");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _defineProperty(obj, key, value) { key = _toPropertyKey(key); if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
function _toPropertyKey(arg) { var key = _toPrimitive(arg, "string"); return typeof key === "symbol" ? key : String(key); }
function _toPrimitive(input, hint) { if (typeof input !== "object" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || "default"); if (typeof res !== "object") return res; throw new TypeError("@@toPrimitive must return a primitive value."); } return (hint === "string" ? String : Number)(input); }
const FULLSTORY_PLUGIN_CONFIG_DEFAULTS = {
  enableFSSessionUrlInEvents: true,
  allowlistAllTrackEvents: false,
  enableIdentifyEvents: true,
  enableSendScreenAsEvents: false,
  enableGroupTraitsAsUserVars: false
};
class FullStoryPlugin extends _analyticsReactNative.Plugin {
  constructor(userConfig) {
    super();
    _defineProperty(this, "enableFSSessionURLInEvents", void 0);
    _defineProperty(this, "allowlistAllTrackEvents", void 0);
    _defineProperty(this, "allowlistTrackEvents", void 0);
    _defineProperty(this, "enableIdentifyEvents", void 0);
    _defineProperty(this, "enableSendScreenAsEvents", void 0);
    _defineProperty(this, "enableGroupTraitsAsUserVars", void 0);
    _defineProperty(this, "fsSessionUrl", '');
    _defineProperty(this, "type", _analyticsReactNative.PluginType.enrichment);
    _reactNative.default.onReady().then(result => {
      this.fsSessionUrl = result.replayStartUrl;
    });
    const config = {
      ...FULLSTORY_PLUGIN_CONFIG_DEFAULTS,
      ...userConfig
    };
    this.enableFSSessionURLInEvents = config.enableFSSessionUrlInEvents;
    this.allowlistAllTrackEvents = config.allowlistAllTrackEvents;
    this.allowlistTrackEvents = config.allowlistTrackEvents;
    this.enableIdentifyEvents = config.enableIdentifyEvents;
    this.enableSendScreenAsEvents = config.enableSendScreenAsEvents;
    this.enableGroupTraitsAsUserVars = config.enableGroupTraitsAsUserVars;
  }
  execute(event) {
    switch (event.type) {
      case 'track':
        if (this.allowlistAllTrackEvents || this.allowlistTrackEvents && this.allowlistTrackEvents.includes(event.event)) {
          const fsProps = new _FSProperties.FSProperties(event.properties);
          _reactNative.default.event(event.event, fsProps.getProperties());
          if (this.enableFSSessionURLInEvents && this.fsSessionUrl) {
            this.addFSUrlToProperties(event);
          }
        }
        break;
      case 'identify':
        if (this.enableIdentifyEvents) {
          const traits = new _FSProperties.FSProperties(event.traits).getProperties();
          _reactNative.default.identify(event.userId || '', traits);
        }
        break;
      case 'screen':
        if (this.enableSendScreenAsEvents) {
          const properties = new _FSProperties.FSProperties(event.properties).getProperties();
          _reactNative.default.event('Segment Screen: ' + event.name, properties);
          if (this.enableFSSessionURLInEvents && this.fsSessionUrl) {
            this.addFSUrlToProperties(event);
          }
        }
        break;
      case 'group':
        let traits;
        if (this.enableGroupTraitsAsUserVars) {
          traits = new _FSProperties.FSProperties(event.traits).getProperties();
        }
        _reactNative.default.setUserVars({
          groupID: event.groupId,
          ...traits
        });
        break;
    }
    return event;
  }
  reset() {
    _reactNative.default.anonymize();
  }
  addFSUrlToProperties(event) {
    if (!event.properties) {
      event.properties = {};
    }
    event.properties.fullstoryUrl = this.fsSessionUrl;
  }
}
exports.FullStoryPlugin = FullStoryPlugin;
//# sourceMappingURL=FullStoryConfig.js.map